@@ -745,6 +745,7 @@ function hideadddirectoryform() {
 }
 
 function index_click() {
+    $('#filemanmode').val("");
     $('#wait span.msg').html("Loading document on the server...<br/>(this may take a while for large documents)");
     $('#wait').show();
 }
@@ -755,6 +756,11 @@ function clickparent() {
 
 function submitfilemanager(filemanmode) {
     //Submit a file management operation (sets a mode and submits the HTML form)
+    if (filemanmode == "delete") {
+        if (!confirm("Are you sure you want to delete the selected documents?")) {
+            return;
+        }
+    }
     $('#filemanmode').val(filemanmode);
     $('#filemanform').submit();
 }
